<?php

/**
 * Theme settings
 *
 * @param array $settings
 * @return array
 */
function theme_app_settings($settings) {
    return json_decode(<<<JSON
    {
    "colorScheme": {
        "bodyColors": [
            "#111111",
            "#ffffff"
        ],
        "bgColor": "#ffffff",
        "colors": [
            "#eaeec5",
            "#aba12f",
            "#b5d8ea",
            "#bf9a42",
            "#80a4bf"
        ],
        "customColors": [
            "#000000",
            "#60ed0b",
            "#f00707",
            "#f8fa00",
            "#d6a8a8",
            "#eaeec5"
        ],
        "shadingContrast": "body-alt-color",
        "whiteContrast": "body-color",
        "bgContrast": "body-color",
        "name": "u11"
    },
    "fontScheme": {
        "name": "custom-font-family-65",
        "default": true,
        "fonts": {
            "heading": "Tangerine",
            "text": "Verdana, sans-serif",
            "accent": "Arial, sans-serif",
            "headingTitle": "Tangerine",
            "textTitle": "Verdana, sans-serif"
        }
    },
    "typography": {
        "name": "custom-page-typography-1",
        "title": {
            "font-size": 4.5,
            "line-height": "1_1",
            "margin-top": 20,
            "margin-bottom": 20,
            "font-weight": "700"
        },
        "subtitle": {
            "font-weight": "400",
            "font-size": 2.25,
            "line-height": "1_1",
            "margin-top": 20,
            "margin-bottom": 20
        },
        "h1": {
            "font-size": 3,
            "line-height": "1_1",
            "margin-top": 20,
            "margin-bottom": 20,
            "font-weight": "700"
        },
        "h2": {
            "font-size": 2.25,
            "line-height": "1_1",
            "margin-top": 20,
            "margin-bottom": 20,
            "font-weight": "700"
        },
        "h3": {
            "font-size": 1.875,
            "line-height": "1_2",
            "margin-top": 20,
            "margin-bottom": 20,
            "font-weight": "700"
        },
        "h4": {
            "font-size": 1.5,
            "line-height": "1_2",
            "margin-top": 20,
            "margin-bottom": 20,
            "font-weight": "700"
        },
        "h5": {
            "font-size": 1.25,
            "line-height": "1_2",
            "margin-top": 20,
            "margin-bottom": 20,
            "font-weight": "700"
        },
        "h6": {
            "font-size": 3,
            "line-height": "1_2",
            "margin-top": 20,
            "margin-bottom": 20,
            "font-weight": "700",
            "font-style": "",
            "text-decoration": "",
            "text-transform": "",
            "letter-spacing": "",
            "text-color": "",
            "border-color": "",
            "border-style": "",
            "color": "",
            "border": "",
            "button-shape": "",
            "border-radius": "",
            "underline": "",
            "gradient": "",
            "font": ""
        },
        "largeText": {
            "font-size": 1.25,
            "margin-top": 20,
            "margin-bottom": 20,
            "font-weight": "400"
        },
        "smallText": {
            "font-size": 0.875,
            "margin-top": 20,
            "margin-bottom": 20,
            "font-weight": "500",
            "font": "Verdana, sans-serif"
        },
        "text": {
            "margin-top": 20,
            "margin-bottom": 20,
            "font-weight": "500",
            "font": "Verdana, sans-serif",
            "font-size": 1,
            "line-height": "1.2"
        },
        "link": {
            "text-color": "body-color",
            "margin-top": 10,
            "margin-bottom": 10,
            "border": "0",
            "border-style": "none",
            "border-color": false,
            "padding-bottom": false,
            "font-size": 0.875,
            "text-hover-color": "palette-4-dark-2",
            "line-height": "1.2",
            "font-weight": "700",
            "font": "Verdana, sans-serif",
            "underline": "no-underline"
        },
        "button": {
            "color": false,
            "margin-top": 20,
            "margin-bottom": 20,
            "button-shape": "round",
            "border-radius": 5,
            "border-color": "grey-dark-1",
            "border-style": "solid",
            "border": 2,
            "hover-border-color": "custom-color-3",
            "active-border-color": "custom-color-2",
            "hover-color": false,
            "active-color": false,
            "gradient": "linear-gradient(var(--palette-3-base), var(--palette-5-base))",
            "padding-left": 30,
            "padding-right": 30
        },
        "blockquote": {
            "font-style": "italic",
            "indent": 20,
            "border": 5,
            "border-color": "palette-5-light-1",
            "margin-top": 20,
            "margin-bottom": 20,
            "font": "Verdana, sans-serif",
            "text-color": "palette-5-dark-2",
            "border-style": "solid",
            "line-height": "1.2",
            "font-size": 0.875
        },
        "metadata": {
            "margin-top": 20,
            "margin-bottom": 20
        },
        "list": {
            "margin-top": 20,
            "margin-bottom": 20,
            "font-size": 0.875,
            "font": "Arial, sans-serif"
        },
        "orderedlist": {
            "margin-top": 20,
            "margin-bottom": 20,
            "font": "Arial, sans-serif",
            "font-weight": "400",
            "indent": 5,
            "spacing": 1
        },
        "postContent": {
            "margin-top": 20,
            "margin-bottom": 20
        },
        "theme": {
            "gradient": "",
            "image": ""
        },
        "htmlBaseSize": 16
    }
}
JSON
, true);
}
add_filter('nicepage_theme_settings', 'theme_app_settings');

function theme_analytics() {
?>
    
<?php
}
add_action('wp_head', 'theme_analytics', 0);


function theme_favicon() {
    $custom_favicon_id = get_theme_mod('custom_favicon');
    @list($favicon_src, ,) = wp_get_attachment_image_src($custom_favicon_id, 'full');
    if (!$favicon_src) {
        $favicon_src = "favicon.jpg";
        if ($favicon_src) {
            $favicon_src = get_template_directory_uri() . '/images/' . $favicon_src;
        }
    }

    if ($favicon_src) {
        echo "<link rel=\"icon\" href=\"$favicon_src\">";
    }
}
add_action('wp_head', 'theme_favicon');